@@ -24,6 +24,24 @@ def null_id() -> str:
     return uuid.UUID(int=0).hex
 
 
+def namespaced_id(namespace_id: str, entity_name: str) -> str:
+    """Return an ID for a named entity whose name is unique within a namespace
+    corresponding to another entity ID.
+
+    This is used to model "child" resources that exist within the context of
+    a "parent".
+
+    :param namespace_id: The ID of the namespace.
+    :type namespace_id: str
+    :param entity_name: A name that is unique in the context of the namespace.
+    :type entity_name: str
+    :returns: The unique identifier of this (namespace, name)
+        combination -- a hex string representation of a UUID.
+    :rtype: str
+    """
+    return uuid.uuid5(uuid.UUID(hex=namespace_id), entity_name).hex
+
+
 def replication_id(evaluation_id: str, replication_index: int) -> str:
     """Return a unique identifier for a replication within an evaluation. Replications
     in different evaluations will have different identifiers, so datasets from different
@@ -37,4 +55,4 @@ def replication_id(evaluation_id: str, replication_index: int) -> str:
         combination -- a hex string representation of a UUID.
     :rtype: str
     """
-    return uuid.uuid5(uuid.UUID(hex=evaluation_id), str(replication_index)).hex
+    return namespaced_id(evaluation_id, str(replication_index))
