@@ -16,6 +16,7 @@ from typing_extensions import Annotated
 
 from .base import DyffSchemaBaseModel, JsonMergePatchSemantics
 from .platform import (
+    ChallengeNewsItem,
     ChallengeTask,
     ChallengeTaskExecutionEnvironment,
     ChallengeTaskSchedule,
@@ -165,6 +166,11 @@ class ChallengeContentPatch(DyffSchemaBaseModel):
         description="Edits to make to the page portion of the content.",
     )
 
+    news: Optional[dict[str, ChallengeNewsItem]] = pydantic.Field(
+        default=None,
+        description="News items to display in the challenge news feed.",
+    )
+
     @field_serializer("page")
     def _serialize_page(self, page: ChallengeContentPagePatch, _info):
         return page.model_dump(mode=_info.mode)
