@@ -5,6 +5,10 @@ import base64
 import hashlib
 import typing
 
+import pydantic
+
+from ..base import DyffSchemaBaseModel
+
 if typing.TYPE_CHECKING:
     from _typeshed import ReadableBuffer
 
@@ -25,3 +29,12 @@ def file_digest(algorithm: str, path: str) -> bytes:
         while n := f.readinto(mv):
             h.update(mv[:n])
     return h.digest()
+
+
+class Media(DyffSchemaBaseModel):
+    """Binary-encoded data with accompanying media type."""
+
+    data: bytes = pydantic.Field(description="The binary data")
+    mediaType: str = pydantic.Field(
+        description="The IETF Media Type (MIME type) of the data"
+    )
